# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: IssuingAttributes.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='IssuingAttributes.proto',
  package='sharepubapi_v1',
  syntax='proto3',
  serialized_options=_b('\n$com.yoti.api.client.spi.remote.protoB\026IssuingAttributesProtoZ\016yotiprotoshare\252\002\030Yoti.Auth.ProtoBuf.Share\312\002\020Yoti\\Sharepubapi\342\002\034Yoti\\Sharepubapi\\GPBMetadata\352\002\031Yoti.Protobuf.Sharepubapi'),
  serialized_pb=_b('\n\x17IssuingAttributes.proto\x12\x0esharepubapi_v1\"Y\n\x11IssuingAttributes\x12\x13\n\x0b\x65xpiry_date\x18\x01 \x01(\t\x12/\n\x0b\x64\x65\x66initions\x18\x02 \x03(\x0b\x32\x1a.sharepubapi_v1.Definition\"\x1a\n\nDefinition\x12\x0c\n\x04name\x18\x01 \x01(\tB\xb7\x01\n$com.yoti.api.client.spi.remote.protoB\x16IssuingAttributesProtoZ\x0eyotiprotoshare\xaa\x02\x18Yoti.Auth.ProtoBuf.Share\xca\x02\x10Yoti\\Sharepubapi\xe2\x02\x1cYoti\\Sharepubapi\\GPBMetadata\xea\x02\x19Yoti.Protobuf.Sharepubapib\x06proto3')
)




_ISSUINGATTRIBUTES = _descriptor.Descriptor(
  name='IssuingAttributes',
  full_name='sharepubapi_v1.IssuingAttributes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expiry_date', full_name='sharepubapi_v1.IssuingAttributes.expiry_date', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='definitions', full_name='sharepubapi_v1.IssuingAttributes.definitions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43,
  serialized_end=132,
)


_DEFINITION = _descriptor.Descriptor(
  name='Definition',
  full_name='sharepubapi_v1.Definition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='sharepubapi_v1.Definition.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=160,
)

_ISSUINGATTRIBUTES.fields_by_name['definitions'].message_type = _DEFINITION
DESCRIPTOR.message_types_by_name['IssuingAttributes'] = _ISSUINGATTRIBUTES
DESCRIPTOR.message_types_by_name['Definition'] = _DEFINITION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IssuingAttributes = _reflection.GeneratedProtocolMessageType('IssuingAttributes', (_message.Message,), dict(
  DESCRIPTOR = _ISSUINGATTRIBUTES,
  __module__ = 'IssuingAttributes_pb2'
  # @@protoc_insertion_point(class_scope:sharepubapi_v1.IssuingAttributes)
  ))
_sym_db.RegisterMessage(IssuingAttributes)

Definition = _reflection.GeneratedProtocolMessageType('Definition', (_message.Message,), dict(
  DESCRIPTOR = _DEFINITION,
  __module__ = 'IssuingAttributes_pb2'
  # @@protoc_insertion_point(class_scope:sharepubapi_v1.Definition)
  ))
_sym_db.RegisterMessage(Definition)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ExtraData.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import DataEntry_pb2 as DataEntry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ExtraData.proto',
  package='sharepubapi_v1',
  syntax='proto3',
  serialized_options=_b('\n$com.yoti.api.client.spi.remote.protoB\016ExtraDataProtoZ\016yotiprotoshare\252\002\030Yoti.Auth.ProtoBuf.Share\312\002\020Yoti\\Sharepubapi\342\002\034Yoti\\Sharepubapi\\GPBMetadata\352\002\031Yoti.Protobuf.Sharepubapi'),
  serialized_pb=_b('\n\x0f\x45xtraData.proto\x12\x0esharepubapi_v1\x1a\x0f\x44\x61taEntry.proto\"4\n\tExtraData\x12\'\n\x04list\x18\x01 \x03(\x0b\x32\x19.sharepubapi_v1.DataEntryB\xaf\x01\n$com.yoti.api.client.spi.remote.protoB\x0e\x45xtraDataProtoZ\x0eyotiprotoshare\xaa\x02\x18Yoti.Auth.ProtoBuf.Share\xca\x02\x10Yoti\\Sharepubapi\xe2\x02\x1cYoti\\Sharepubapi\\GPBMetadata\xea\x02\x19Yoti.Protobuf.Sharepubapib\x06proto3')
  ,
  dependencies=[DataEntry__pb2.DESCRIPTOR,])




_EXTRADATA = _descriptor.Descriptor(
  name='ExtraData',
  full_name='sharepubapi_v1.ExtraData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='list', full_name='sharepubapi_v1.ExtraData.list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=104,
)

_EXTRADATA.fields_by_name['list'].message_type = DataEntry__pb2._DATAENTRY
DESCRIPTOR.message_types_by_name['ExtraData'] = _EXTRADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExtraData = _reflection.GeneratedProtocolMessageType('ExtraData', (_message.Message,), dict(
  DESCRIPTOR = _EXTRADATA,
  __module__ = 'ExtraData_pb2'
  # @@protoc_insertion_point(class_scope:sharepubapi_v1.ExtraData)
  ))
_sym_db.RegisterMessage(ExtraData)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: DataEntry.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='DataEntry.proto',
  package='sharepubapi_v1',
  syntax='proto3',
  serialized_options=_b('\n$com.yoti.api.client.spi.remote.protoB\016DataEntryProtoZ\016yotiprotoshare\252\002\030Yoti.Auth.ProtoBuf.Share\312\002\020Yoti\\Sharepubapi\342\002\034Yoti\\Sharepubapi\\GPBMetadata\352\002\031Yoti.Protobuf.Sharepubapi'),
  serialized_pb=_b('\n\x0f\x44\x61taEntry.proto\x12\x0esharepubapi_v1\"\xdd\x01\n\tDataEntry\x12,\n\x04type\x18\x01 \x01(\x0e\x32\x1e.sharepubapi_v1.DataEntry.Type\x12\r\n\x05value\x18\x02 \x01(\x0c\"\x92\x01\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\x0b\n\x07INVOICE\x10\x01\x12\x17\n\x13PAYMENT_TRANSACTION\x10\x02\x12\x0c\n\x08LOCATION\x10\x03\x12\x0f\n\x0bTRANSACTION\x10\x04\x12\x1b\n\x17\x41GE_VERIFICATION_SECRET\x10\x05\x12\x19\n\x15THIRD_PARTY_ATTRIBUTE\x10\x06\x42\xaf\x01\n$com.yoti.api.client.spi.remote.protoB\x0e\x44\x61taEntryProtoZ\x0eyotiprotoshare\xaa\x02\x18Yoti.Auth.ProtoBuf.Share\xca\x02\x10Yoti\\Sharepubapi\xe2\x02\x1cYoti\\Sharepubapi\\GPBMetadata\xea\x02\x19Yoti.Protobuf.Sharepubapib\x06proto3')
)



_DATAENTRY_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='sharepubapi_v1.DataEntry.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVOICE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_TRANSACTION', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTION', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_VERIFICATION_SECRET', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THIRD_PARTY_ATTRIBUTE', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=111,
  serialized_end=257,
)
_sym_db.RegisterEnumDescriptor(_DATAENTRY_TYPE)


_DATAENTRY = _descriptor.Descriptor(
  name='DataEntry',
  full_name='sharepubapi_v1.DataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='sharepubapi_v1.DataEntry.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='sharepubapi_v1.DataEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATAENTRY_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=257,
)

_DATAENTRY.fields_by_name['type'].enum_type = _DATAENTRY_TYPE
_DATAENTRY_TYPE.containing_type = _DATAENTRY
DESCRIPTOR.message_types_by_name['DataEntry'] = _DATAENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataEntry = _reflection.GeneratedProtocolMessageType('DataEntry', (_message.Message,), dict(
  DESCRIPTOR = _DATAENTRY,
  __module__ = 'DataEntry_pb2'
  # @@protoc_insertion_point(class_scope:sharepubapi_v1.DataEntry)
  ))
_sym_db.RegisterMessage(DataEntry)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



from abc import ABCMeta
from abc import abstractmethod

from yoti_python_sdk.utils import YotiSerializable


class RequestedCheck(YotiSerializable):
    """
    Requests creation of a Check to be performed on a document
    """

    __metaclass__ = ABCMeta

    @property
    @abstractmethod
    def type(self):
        """
        Return the type of the Check to create

        :return: the type
        :rtype: str
        """
        raise NotImplementedError

    @property
    @abstractmethod
    def config(self):
        """
        Return configuration to apply to the Check

        :return: the configuration
        """
        raise NotImplementedError

    def to_json(self):
        return {"type": self.type, "config": self.config}



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from yoti_python_sdk.utils import YotiSerializable


class SessionSpec(YotiSerializable):
    """
    Definition for the Doc Scan Session to be created
    """

    def __init__(
        self,
        client_session_token_ttl,
        resources_ttl,
        user_tracking_id,
        notifications,
        sdk_config,
        requested_checks=None,
        requested_tasks=None,
    ):
        """
        :param client_session_token_ttl: the client session token TTL
        :type client_session_token_ttl: int
        :param resources_ttl: the resources TTL
        :type resources_ttl: int
        :param user_tracking_id: the user tracking ID
        :type user_tracking_id: str
        :param notifications: the notification configuration
        :type notifications: NotificationConfig
        :param sdk_config: the SDK configuration
        :type sdk_config: SdkConfig
        :param requested_checks: the list of requested checks
        :type requested_checks: list[RequestedCheck]
        :param requested_tasks: the list of requested tasks
        :type requested_tasks: list[RequestedTask]
        """
        if requested_tasks is None:
            requested_tasks = []
        if requested_checks is None:
            requested_checks = []

        self.__client_session_token_ttl = client_session_token_ttl
        self.__resources_ttl = resources_ttl
        self.__user_tracking_id = user_tracking_id
        self.__notifications = notifications
        self.__sdk_config = sdk_config
        self.__requested_checks = requested_checks
        self.__requested_tasks = requested_tasks

    @property
    def client_session_token_ttl(self):
        """
        Client-session-token time-to-live to apply to the created Session

        :return: the client-session-token time-to-live
        :rtype: int
        """
        return self.__client_session_token_ttl

    @property
    def resources_ttl(self):
        """
        Time-to-live used for all Resources created in the course of the session

        :return: the time-to-live for Resources
        :rtype: int
        """
        return self.__resources_ttl

    @property
    def user_tracking_id(self):
        """
        User tracking ID, for the Relying Business to track returning users

        :return: the user tracking ID
        :rtype: str
        """
        return self.__user_tracking_id

    @property
    def notifications(self):
        """
        :class:`NotificationConfig` for configuring call-back messages

        :return: the notification config
        :rtype: NotificationConfig
        """
        return self.__notifications

    @property
    def sdk_config(self):
        """
        Retrieves the SDK configuration set of the session specification

        :return: the SDK config
        :rtype: SdkConfig
        """
        return self.__sdk_config

    @property
    def requested_checks(self):
        """
        List of :class:`RequestedCheck` objects defining the Checks to be performed
        on each Document

        :return: the requested checks
        :rtype: list[RequestedCheck]
        """
        return self.__requested_checks

    @property
    def requested_tasks(self):
        """
        List of :class:`RequestedTask` objects defining the Tasks to be performed
        on each Document

        :return: the requested tasks
        :rtype: list[RequestedTask]
        """
        return self.__requested_tasks

    def to_json(self):
        return {
            "client_session_token_ttl": self.client_session_token_ttl,
            "resources_ttl": self.resources_ttl,
            "user_tracking_id": self.user_tracking_id,
            "notifications": self.notifications,
            "requested_checks": self.requested_checks,
            "requested_tasks": self.requested_tasks,
            "sdk_config": self.sdk_config,
        }


class SessionSpecBuilder(object):
    """
    Builder to assist the creation of :class:`SessionSpec`
    """

    def __init__(self):
        self.__client_session_token_ttl = None
        self.__resources_ttl = None
        self.__user_tracking_id = None
        self.__notifications = None
        self.__sdk_config = None
        self.__requested_checks = []
        self.__requested_tasks = []

    def with_client_session_token_ttl(self, value):
        """
        Sets the client session token TTL (time-to-live)

        :param value: the client session token TTL
        :type value: int
        :return: the builder
        :rtype: SessionSpecBuilder
        """
        self.__client_session_token_ttl = value
        return self

    def with_resources_ttl(self, value):
        """
        Sets the resources TTL (time-to-live)

        :param value: the resources TTL
        :type value: int
        :return: the builder
        :rtype: SessionSpecBuilder
        """
        self.__resources_ttl = value
        return self

    def with_user_tracking_id(self, value):
        """
        Sets the user tracking ID

        :param value: the user tracking ID
        :type value: str
        :return: the builder
        :rtype: SessionSpecBuilder
        """
        self.__user_tracking_id = value
        return self

    def with_notifications(self, notifications):
        """
        Sets the notification configuration

        :param notifications: the notification config
        :type notifications: NotificationConfig
        :return: the builder
        :rtype: SessionSpecBuilder
        """
        self.__notifications = notifications
        return self

    def with_requested_check(self, check):
        """
        Adds a :class:`RequestedCheck` to the list

        :param check: the check to add
        :type check: RequestedCheck
        :return: the builder
        :rtype: SessionSpecBuilder
        """
        self.__requested_checks.append(check)
        return self

    def with_requested_task(self, task):
        """
        Adds a :class:`RequestedTask` to the list

        :param task: the task to add
        :type task: RequestedTask
        :return: the builder
        :rtype: SessionSpecBuilder
        """
        self.__requested_tasks.append(task)
        return self

    def with_sdk_config(self, value):
        """
        Sets the SDK configuration

        :param value: the SDK config
        :type value: SdkConfig
        :return: the builder
        :rtype: SessionSpecBuilder
        """
        self.__sdk_config = value
        return self

    def build(self):
        """
        Builds a :class:`SessionSpec` using the supplied values

        :return: the built Session Specification
        :rtype: SessionSpec
        """
        return SessionSpec(
            self.__client_session_token_ttl,
            self.__resources_ttl,
            self.__user_tracking_id,
            self.__notifications,
            self.__sdk_config,
            self.__requested_checks,
            self.__requested_tasks,
        )



from .session.create.check.document_authenticity import (
    RequestedDocumentAuthenticityCheckBuilder,
)
from .session.create.check.face_match import RequestedFaceMatchCheckBuilder
from .session.create.check.liveness import RequestedLivenessCheckBuilder
from .session.create.task.text_extraction import RequestedTextExtractionTaskBuilder
from .session.create.notification_config import NotificationConfigBuilder
from .session.create.sdk_config import SdkConfigBuilder
from .session.create.session_spec import SessionSpecBuilder
from .client import DocScanClient

__all__ = [
    RequestedDocumentAuthenticityCheckBuilder,
    RequestedLivenessCheckBuilder,
    RequestedFaceMatchCheckBuilder,
    RequestedTextExtractionTaskBuilder,
    SessionSpecBuilder,
    NotificationConfigBuilder,
    SdkConfigBuilder,
    DocScanClient,
]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import copy


class ThirdPartyAttributeExtension(object):
    THIRDPARTY_ATTRIBUTE = "THIRD_PARTY_ATTRIBUTE"

    def __init__(self):
        self.__extension = {}
        self.__extension["type"] = self.THIRDPARTY_ATTRIBUTE
        self.__extension["content"] = {"expiry_date": None, "definitions": []}

    def with_expiry_date(self, expiry_date):
        self.__extension["content"]["expiry_date"] = expiry_date.isoformat()
        return self

    def with_definitions(self, *names):
        self.__extension["content"]["definitions"].extend([{"name": s} for s in names])
        return self

    def build(self):
        return copy.deepcopy(self.__extension)



from .document_authenticity import RequestedDocumentAuthenticityCheckBuilder
from .face_match import RequestedFaceMatchCheckBuilder
from .liveness import RequestedLivenessCheckBuilder

__all__ = [
    RequestedDocumentAuthenticityCheckBuilder,
    RequestedFaceMatchCheckBuilder,
    RequestedLivenessCheckBuilder,
]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

ID_DOCUMENT_AUTHENTICITY = "ID_DOCUMENT_AUTHENTICITY"
ID_DOCUMENT_TEXT_DATA_CHECK = "ID_DOCUMENT_TEXT_DATA_CHECK"
ID_DOCUMENT_TEXT_DATA_EXTRACTION = "ID_DOCUMENT_TEXT_DATA_EXTRACTION"
ID_DOCUMENT_FACE_MATCH = "ID_DOCUMENT_FACE_MATCH"
LIVENESS = "LIVENESS"
ZOOM = "ZOOM"

CAMERA = "CAMERA"
CAMERA_AND_UPLOAD = "CAMERA_AND_UPLOAD"

RESOURCE_UPDATE = "RESOURCE_UPDATE"
TASK_COMPLETION = "TASK_COMPLETION"
CHECK_COMPLETION = "CHECK_COMPLETION"
SESSION_COMPLETION = "SESSION_COMPLETION"

ALWAYS = "ALWAYS"
FALLBACK = "FALLBACK"
NEVER = "NEVER"



# -*- coding: utf-8 -*-
from setuptools import find_packages
from setuptools import setup

long_description = (
    "This package contains the tools you need to quickly "
    "integrate your Python back-end with Yoti, so that your "
    "users can share their identity details with your "
    "application in a secure and trusted way."
)

version = {}
with open("yoti_python_sdk/version.py") as fp:
    exec(fp.read(), version)

setup(
    name="yoti",
    version=version["__version__"],
    packages=find_packages(include=["yoti_python_sdk", "yoti_python_sdk.*"]),
    license="MIT",
    description="The Yoti Python SDK, providing API support for Login, Verify (2FA) and Age Verification.",
    long_description=long_description,
    url="https://github.com/getyoti/yoti-python-sdk",
    author="Yoti",
    author_email="websdk@yoti.com",
    install_requires=[
        "deprecated==1.2.6",
        "cryptography>=2.2.1",
        "protobuf>=3.1.0",
        "requests>=2.11.1",
        "future>=0.11.0",
        "asn1==2.2.0",
        "pyopenssl>=18.0.0",
        "iso8601==0.1.12",
    ],
    extras_require={
        "examples": [
            "Django>1.11.16",
            "Flask>=0.10",
            "python-dotenv>=0.7.1",
            "django-sslserver>=0.2",
            "Werkzeug==0.15.3",
        ],
        "dev": [
            "pre-commit==1.17.0",
            "pytest>=3.6.0",
            "pytest-cov>=2.7.1",
            "pylint==1.9.4",
            "pylint-exit>=1.1.0",
            "python-coveralls==2.9.3",
            "coverage==4.5.4",
            "mock==2.0.0",
            "virtualenv==20.0.13",
        ],
    },
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    keywords="yoti sdk 2FA multifactor authentication verification identity login register verify 2Factor",
)



from .check.document_authenticity import RequestedDocumentAuthenticityCheckBuilder
from .check.face_match import RequestedFaceMatchCheckBuilder
from .check.liveness import RequestedLivenessCheckBuilder
from .notification_config import NotificationConfigBuilder
from .session_spec import SessionSpecBuilder
from .sdk_config import SdkConfigBuilder

__all__ = [
    RequestedDocumentAuthenticityCheckBuilder,
    RequestedFaceMatchCheckBuilder,
    RequestedLivenessCheckBuilder,
    NotificationConfigBuilder,
    SessionSpecBuilder,
    SdkConfigBuilder,
]



class DocScanException(Exception):
    """
    Exception thrown by the Yoti Doc Scan client
    when an error has occurred when communicating with the API
    """

    def __init__(self, message, response):
        """
        :param message: the exception message
        :type message: str
        :param response: the http response
        :type response: requests.Response
        """
        Exception.__init__(self)

        self.__message = message
        self.__response = response

    @property
    def message(self):
        """
        Get the specific exception message

        :return: the exception message
        :rtype: str
        """
        return self.__message

    @property
    def status_code(self):
        """
        Get the status code of the HTTP response

        :return: the status code
        :rtype: int or None
        """
        return self.__response.status_code

    @property
    def text(self):
        """
        Return the HTTP response body as text

        :return: the body as text
        :rtype: str
        """
        return self.__response.text

    @property
    def content(self):
        """
        Return the HTTP response body as bytes

        :return: the body as bytes
        :rtype: bytearray or None
        """
        return self.__response.content

    def __str__(self):
        return self.__message
